@@ -54,11 +54,13 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.net.URI;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.Optional;
 import java.util.Set;
 import java.util.SortedSet;
 import java.util.TreeSet;
@@ -70,6 +72,7 @@ import java.util.concurrent.FutureTask;
 import java.util.concurrent.atomic.AtomicReference;
 import org.slf4j.Logger;
 import com.openexchange.exception.OXException;
+import com.openexchange.filestore.DestroyAwareFileStorage;
 import com.openexchange.filestore.FileStorage;
 import com.openexchange.filestore.FileStorageCodes;
 import com.openexchange.filestore.swift.chunkstorage.Chunk;
@@ -87,26 +90,34 @@ import com.openexchange.java.util.UUIDs;
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  * @since v7.8.2
  */
-public class SwiftFileStorage implements FileStorage {
+public class SwiftFileStorage implements DestroyAwareFileStorage {
 
     private final SwiftClient client;
     private final ChunkStorage chunkStorage;
     private final AtomicReference<Future<Void>> containerCreatedTask;
+    private final URI uri;
 
     /**
      * Initializes a new {@link SwiftFileStorage}.
      *
+     * @param uri The URI that fully qualifies this file storage
      * @param services A service lookup reference
      * @param client The spoxyd client to use
      * @param chunkStorage The underlying chunk storage
      */
-    public SwiftFileStorage(SwiftClient client, ChunkStorage chunkStorage) {
+    public SwiftFileStorage(URI uri, SwiftClient client, ChunkStorage chunkStorage) {
         super();
+        this.uri = uri;
         this.client = client;
         this.chunkStorage = chunkStorage;
         containerCreatedTask = new AtomicReference<Future<Void>>(null);
     }
 
+    @Override
+    public void onDestroyed() {
+        client.shutdown();
+    }
+
     private void checkOrCreateContainer() throws OXException {
         Future<Void> f = containerCreatedTask.get();
         if (null == f) {
@@ -147,6 +158,11 @@ public class SwiftFileStorage implements FileStorage {
         }
     }
 
+    @Override
+    public URI getUri() {
+        return uri;
+    }
+
     @Override
     public String saveNewFile(InputStream file) throws OXException {
         File tmpFile = null;
@@ -155,8 +171,9 @@ public class SwiftFileStorage implements FileStorage {
              * spool to file
              */
             if (!(file instanceof FileInputStream)) {
-                tmpFile = TempFileHelper.getInstance().newTempFile();
-                if (tmpFile != null) {
+                Optional<File> optionalTempFile = TempFileHelper.getInstance().newTempFile();
+                if (optionalTempFile.isPresent()) {
+                    tmpFile = optionalTempFile.get();
                     file = Streams.transferToFileAndCreateStream(file, tmpFile);
                 }
             }
@@ -297,8 +314,9 @@ public class SwiftFileStorage implements FileStorage {
              * spool to file
              */
             if (!(file instanceof FileInputStream)) {
-                tmpFile = TempFileHelper.getInstance().newTempFile();
-                if (tmpFile != null) {
+                Optional<File> optionalTempFile = TempFileHelper.getInstance().newTempFile();
+                if (optionalTempFile.isPresent()) {
+                    tmpFile = optionalTempFile.get();
                     file = Streams.transferToFileAndCreateStream(file, tmpFile);
                 }
             }
