@@ -60,6 +60,7 @@ import com.openexchange.database.migration.DBMigrationExecutorService;
 import com.openexchange.filestore.FileStorageProvider;
 import com.openexchange.filestore.FileStorageUnregisterListener;
 import com.openexchange.filestore.swift.SwiftFileStorageFactory;
+import com.openexchange.filestore.swift.groupware.SwiftConvertToUtf8mb4;
 import com.openexchange.filestore.swift.groupware.SwiftCreateTableService;
 import com.openexchange.filestore.swift.groupware.SwiftCreateTableTask;
 import com.openexchange.filestore.swift.groupware.SwiftDeleteListener;
@@ -109,7 +110,7 @@ public class SwiftActivator extends HousekeepingActivator {
 
         // Register update task, create table job and delete listener
         registerService(CreateTableService.class, new SwiftCreateTableService());
-        registerService(UpdateTaskProviderService.class, new DefaultUpdateTaskProviderService(new SwiftCreateTableTask(this)));
+        registerService(UpdateTaskProviderService.class, new DefaultUpdateTaskProviderService(new SwiftCreateTableTask(), new SwiftConvertToUtf8mb4()));
         registerService(DeleteListener.class, new SwiftDeleteListener());
         registerService(FileStorageUnregisterListener.class, new SwiftFileStorageUnregisterListener());
 
@@ -127,6 +128,7 @@ public class SwiftActivator extends HousekeepingActivator {
     @Override
     protected void stopBundle() throws Exception {
         LOG.info("Stopping bundle: {}", context.getBundle().getSymbolicName());
+
         super.stopBundle();
     }
 
